@@ -1,5 +1,7 @@
 """
-Main interface for kinesisvideo service client paginators.
+Type annotations for kinesisvideo service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisvideo/paginators.html)
 
 Usage::
 
@@ -35,7 +37,7 @@ __all__ = ("ListSignalingChannelsPaginator", "ListStreamsPaginator")
 
 class ListSignalingChannelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSignalingChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.60/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListSignalingChannels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListSignalingChannels)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisvideo/paginators.html#listsignalingchannelspaginator)
     """
 
     def paginate(
@@ -44,13 +46,14 @@ class ListSignalingChannelsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSignalingChannelsOutputTypeDef]:
         """
-        [ListSignalingChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.60/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListSignalingChannels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListSignalingChannels.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisvideo/paginators.html#listsignalingchannelspaginator)
         """
 
 
 class ListStreamsPaginator(Boto3Paginator):
     """
-    [Paginator.ListStreams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.60/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListStreams)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListStreams)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisvideo/paginators.html#liststreamspaginator)
     """
 
     def paginate(
@@ -59,5 +62,6 @@ class ListStreamsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListStreamsOutputTypeDef]:
         """
-        [ListStreams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.60/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListStreams.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/kinesisvideo.html#KinesisVideo.Paginator.ListStreams.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisvideo/paginators.html#liststreamspaginator)
         """
